@@ -9,7 +9,7 @@ class Crush96x96(H5Dataset):
     Data and further information can be found at TODO
     """
 
-    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
         assert sub_set in ['train', 'valid', 'test']
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
@@ -18,13 +18,14 @@ class Crush96x96(H5Dataset):
                              root) / f'{sub_set}.h5',
                          target_key='label',
                          transform=transform,
-                         transform_target=transform_target)
+                         transform_target=transform_target,
+                         num_samples=num_samples)
 
         self.classes = ['C', 'T']  # C=crush and T=tumor
 
     @classmethod
-    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Crush_96', sub_set, transform, transform_target)
+    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
+        return cls('/data/ldap/histopathologic/processed_read_only/Crush_96', sub_set, transform, transform_target, num_samples=num_samples)
 
     @staticmethod
     def normalization_values():
