@@ -41,7 +41,7 @@ class Kather224x224(H5Dataset):
     Kather dataset, more information can be found at https://zenodo.org/record/1214456
     """
 
-    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
         assert sub_set in ['train', 'valid', 'test']
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
@@ -54,7 +54,7 @@ class Kather224x224(H5Dataset):
         self.classes = ['ADI', 'BACK', 'DEB', 'LYM', 'MUC', 'MUS', 'NORM', 'STR', 'TUM']
 
     @classmethod
-    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
         return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res224', sub_set, transform, transform_target)
 
     @staticmethod
